"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _react = _interopRequireDefault(require("react"));

var _escapeHtml = _interopRequireDefault(require("escape-html"));

var _fs = _interopRequireDefault(require("fs"));

var _browserPolyfill = require("mwp-app-render/lib/util/browserPolyfill");

var getInnerHTML = function getInnerHTML(__html) {
  return {
    __html: __html
  };
};
/**
 * Module that builds html, head, and body elements
 * And inserts app markup in the body
 *
 * Elements should only be added inside head via Helmet
 * @see {@link https://github.com/nfl/react-helmet}
 *
 * This component solves some "hard" problems related to wrapping a React
 * application in the full HTML markup needed to render it on the server.
 *
 * 1. Passing server-side app state to the client-side JS application - the
 * `window.INITIAL_STATE` setting, which has a few subtle gotchas if
 * implemented differently
 * 2. `<head>` management through `react-helmet` - there are lots of ways of
 * doing this wrong or implementing a fragile/inflexible solution
 * 3. Using an injected variable to write the client JS application bundle path
 * - there are lots of ways to introduce bugs into alternative implementations.
 *
 * @module DOM
 */


var DOM = function DOM(props) {
  var _props$appMarkup = props.appMarkup,
      appMarkup = _props$appMarkup === void 0 ? '' : _props$appMarkup,
      appContext = props.appContext,
      head = props.head,
      _props$initialState = props.initialState,
      initialState = _props$initialState === void 0 ? {} : _props$initialState,
      scripts = props.scripts,
      cssLinks = props.cssLinks;
  var localeCode = initialState.config.requestLanguage;
  var htmlLang = localeCode.split('-')[0];
  /**
   * Add polyfill.io script if needed
   */

  var polyfill = (0, _browserPolyfill.getPolyfill)(appContext.userAgent, localeCode);
  var js = polyfill ? [polyfill].concat((0, _toConsumableArray2.default)(scripts)) : (0, _toConsumableArray2.default)(scripts);
  /**
   * `initialState` has untrusted user-generated content that needs to be
   * written into the DOM inside a <script> tag.
   *
   * It needs to be transformed into a plain object containing only escaped content
   */
  // stringify the whole object so that it can be escaped in one pass

  var initialStateJson = JSON.stringify(initialState); // escape the string

  var escapedState = (0, _escapeHtml.default)(initialStateJson);
  var APP_RUNTIME = {
    appContext: appContext,
    escapedState: escapedState
  };

  var uxCaptureFilename = require.resolve('@meetup/ux-capture/lib/ux-capture.min.js');

  var uxCaptureJS = _fs.default.readFileSync(uxCaptureFilename, 'utf8');

  return _react.default.createElement("html", {
    lang: htmlLang
  }, _react.default.createElement("head", null, head.title.toComponent(), head.meta.toComponent(), head.link.toComponent(), head.script.toComponent(), _react.default.createElement("script", {
    dangerouslySetInnerHTML: getInnerHTML(uxCaptureJS)
  }), cssLinks && cssLinks.map(function (href, key) {
    return _react.default.createElement("link", {
      rel: "stylesheet",
      type: "text/css",
      href: href,
      key: key
    });
  }), head.style && head.style.toComponent()), _react.default.createElement("body", null, _react.default.createElement("div", {
    id: "outlet",
    dangerouslySetInnerHTML: getInnerHTML(appMarkup)
  }), _react.default.createElement("script", {
    dangerouslySetInnerHTML: getInnerHTML("window.APP_RUNTIME=".concat(JSON.stringify(APP_RUNTIME), ";"))
  }), js.map(function (url, key) {
    return _react.default.createElement("script", {
      src: url,
      key: key
    });
  })));
};

DOM.propTypes = {
  appMarkup: _propTypes.default.string,
  appContext: _propTypes.default.object.isRequired,
  head: _propTypes.default.shape({
    // this is expected to come from Helmet.rewind()
    title: _propTypes.default.shape({
      toComponent: _propTypes.default.func
    }),
    meta: _propTypes.default.shape({
      toComponent: _propTypes.default.func
    }),
    link: _propTypes.default.shape({
      toComponent: _propTypes.default.func
    }),
    script: _propTypes.default.shape({
      toComponent: _propTypes.default.func
    }),
    style: _propTypes.default.shape({
      toComponent: _propTypes.default.func
    })
  }),
  initialState: _propTypes.default.object.isRequired,
  scripts: _propTypes.default.array.isRequired,
  cssLinks: _propTypes.default.arrayOf(_propTypes.default.string)
};
var _default = DOM;
exports.default = _default;
//# sourceMappingURL=Dom.js.map