"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _reactHelmet = _interopRequireDefault(require("react-helmet"));

/**
 * @module StyleWith
 *
 * Adds style module CSS to `head` for both
 * server and client render via `Helmet`.
 *
 *
 * Usage:
 * ```
 * import StyleWith from 'mwp-app-render/lib/components/StyleWith';
 * import styles from './myComponent.module.scss';
 *
 * const MyComponent = (props) => {
 *		return (
 *			<StyleWith styles={[styles]}>
	 *			<p className={styles.someClass}>Hello world!</p>
 *			</StyleWith>
 *		);
 * };
 * ```
 */
var StyleWith = function StyleWith(props) {
  var styles = props.styles,
      children = props.children;
  var moduleCSS = [];
  styles.forEach(function (style) {
    moduleCSS.push(style._getCss()); // eslint-disable-line no-underscore-dangle
  });
  return _react.default.createElement(_react.Fragment, null, _react.default.createElement(_reactHelmet.default, {
    defer: false
  }, _react.default.createElement("style", {
    type: "text/css"
  }, moduleCSS.join(''))), children);
};

StyleWith.propTypes = {
  styles: _propTypes.default.arrayOf(_propTypes.default.object).isRequired
};
var _default = StyleWith;
exports.default = _default;
//# sourceMappingURL=StyleWith.js.map