"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread"));

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _SEOHead = require("./SEOHead");

var MOCK_PROPS = {
  baseUrl: 'https://baseUrl.com',
  imageUrl: 'https://www.mock-image-url.com/',
  ldJson: [{
    foo: 'MOCK_LD_JSON'
  }, {
    bar: 'MOCK_LD_JSON'
  }],
  localeCode: 'es-ES',
  pageDescription: 'mock description',
  pageKeywords: 'mock keywords',
  pageMeta: [{
    mock: 'meta'
  }, {
    more: 'mock'
  }],
  pageTitle: 'mock-page-title',
  robots: false,
  route: '/mock/preview/route'
};

var renderComponent = function renderComponent() {
  var props = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : MOCK_PROPS;
  return (0, _enzyme.shallow)(_react.default.createElement(_SEOHead.SEOHeadComponent, props));
};

describe('SEOHead', function () {
  it('renders component markup', function () {
    expect(renderComponent()).toMatchSnapshot();
  });
  it('strips out undefined json values', function () {
    var props = (0, _objectSpread2.default)({}, MOCK_PROPS, {
      ldJson: [{
        foo: 'bar',
        endDate: undefined,
        startDate: undefined
      }]
    });
    expect((0, _enzyme.shallow)(_react.default.createElement(_SEOHead.SEOHeadComponent, props))).toMatchSnapshot();
  });
  describe('robots', function () {
    var robotsSelector = 'meta[name="robots"]';
    it('defaults to robots "on"', function () {
      var props = (0, _objectSpread2.default)({}, MOCK_PROPS);
      delete props.robots;
      expect(renderComponent(props).find(robotsSelector)).toMatchSnapshot();
    });
    it('explicity turns robots "on"', function () {
      var props = (0, _objectSpread2.default)({}, MOCK_PROPS, {
        robots: true
      });
      delete props.robots;
      expect(renderComponent(props).find(robotsSelector)).toMatchSnapshot();
    });
    it('turns robots "off"', function () {
      var props = (0, _objectSpread2.default)({}, MOCK_PROPS, {
        robots: false
      });
      expect(renderComponent(props).find(robotsSelector)).toMatchSnapshot();
    });
  });
  describe('Custom Open Graph data', function () {
    it('renders custom open graph description', function () {
      var props = (0, _objectSpread2.default)({}, MOCK_PROPS, {
        ogDescription: 'mock custom open graph description'
      });
      expect(renderComponent(props).find('meta[property="og:description"]')).toMatchSnapshot();
    });
  });
  describe('imageUrl', function () {
    it('applies meet script logo to og:image, twitter:image and img_src tags when imageUrl is not provided', function () {
      var props = (0, _objectSpread2.default)({}, MOCK_PROPS, {
        imageUrl: undefined
      });
      expect(renderComponent(props)).toMatchSnapshot();
    });
  });
});
//# sourceMappingURL=seoHead.test.js.map