"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.getPropsAsHTMLAttrs = exports.getOnLoadJS = void 0;

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));

var React = _interopRequireWildcard(require("react"));

var getOnLoadJS = function getOnLoadJS(mark) {
  var onload = "\n\t\tif (window.UXCapture && !window.UXCapture['".concat(mark, "-LOADED']) {\n\t\t\twindow.UXCapture.mark('").concat(mark, "');\n\t\t\twindow.UXCapture['").concat(mark, "-LOADED'] = true;\n\t\t}\n\t"); // Replace newlines and tabs with space characters

  return onload.replace(/[\n\t]+/g, ' ');
};

exports.getOnLoadJS = getOnLoadJS;

var getPropsAsHTMLAttrs = function getPropsAsHTMLAttrs(props) {
  return Object.keys(props).map(function (prop) {
    var attribute = prop; // convert JSX attribute names to HTML syntax
    // Any other special props needed? Add here.
    // @see: https://reactjs.org/docs/dom-elements.html

    if (prop === 'className') {
      attribute = 'class';
    }

    if (prop === 'htmlFor') {
      attribute = 'for';
    } else {
      // handles camelCased attributes like `onLoad`
      attribute = attribute.toLowerCase();
    }

    var raw = props[prop];

    if (typeof raw === 'boolean') {
      return raw ? attribute : '';
    }

    if (raw === null || raw === undefined) {
      return attribute;
    }

    var value = typeof raw === 'string' ? raw : JSON.stringify(raw);

    if (value === undefined) {
      return '';
    }

    return "".concat(attribute, "=\"").concat(value, "\"");
  }).join(' ');
};
/**
 * Creates an image tag with provide props
 * and a UXCapture `onLoad` handler
 *
 * @see example https://github.com/meetup/ux-capture#image-elements
 */


exports.getPropsAsHTMLAttrs = getPropsAsHTMLAttrs;

var UXCaptureImageLoad = function UXCaptureImageLoad(props) {
  var mark = props.mark,
      src = props.src,
      other = (0, _objectWithoutProperties2.default)(props, ["mark", "src"]);
  var onload = getOnLoadJS(mark);
  var otherImgAttrs = getPropsAsHTMLAttrs(other);
  return React.createElement("div", {
    dangerouslySetInnerHTML: {
      __html: "\n\t\t\t\t<img id=\"ux-capture-".concat(mark, "\" src=\"").concat(src, "\" onload=\"").concat(onload, "\" ").concat(otherImgAttrs, " />\n\t\t\t")
    }
  });
};

var _default = UXCaptureImageLoad;
exports.default = _default;
//# sourceMappingURL=UXCaptureImageLoad.js.map