"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread"));

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _UXCaptureStartView = _interopRequireDefault(require("./UXCaptureStartView"));

var MOCK_PROPS = {
  destinationVerfied: ['ux-destination-verified'],
  primaryContentDisplayed: ['ux-primary-content-1', 'ux-primary-content-2'],
  primaryActionAvailable: ['ux-primary-action-available'],
  secondaryContentDisplayed: ['ux-secondary-content-1', 'ux-secondary-content-2', 'ux-secondary-content-3']
};

var renderComponent = function renderComponent() {
  var props = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : MOCK_PROPS;
  return (0, _enzyme.shallow)(_react.default.createElement(_UXCaptureStartView.default, props));
};

describe('UXCaptureStartView', function () {
  it('renders correct markup when all props are defined', function () {
    expect(renderComponent()).toMatchSnapshot();
  });
  it('does not render markup when no zones are defined', function () {
    expect(renderComponent({})).toMatchSnapshot();
  });
  describe('secondaryContentDisplay', function () {
    it('renders correct markup when `secondaryContentDisplayed` not supplied', function () {
      var props = (0, _objectSpread2.default)({}, MOCK_PROPS);
      delete props.secondaryContentDisplayed;
      expect(renderComponent(props)).toMatchSnapshot();
    });
    it('renders correct markup when `secondaryContentDisplayed` is null', function () {
      var props = (0, _objectSpread2.default)({}, MOCK_PROPS);
      props.secondaryContentDisplayed = null;
      expect(renderComponent(props)).toMatchSnapshot();
    });
    it('renders correct markup when `secondaryContentDisplayed` is undefined', function () {
      var props = (0, _objectSpread2.default)({}, MOCK_PROPS);
      props.secondaryContentDisplayed = undefined;
      expect(renderComponent(props)).toMatchSnapshot();
    });
    it('renders correct markup when `secondaryContentDisplayed` is an empty array', function () {
      var props = (0, _objectSpread2.default)({}, MOCK_PROPS);
      props.secondaryContentDisplayed = [];
      expect(renderComponent(props)).toMatchSnapshot();
    });
  });
  describe('primaryActionAvailable', function () {
    it('renders correct markup when `primaryActionAvailable` not supplied', function () {
      var props = (0, _objectSpread2.default)({}, MOCK_PROPS);
      delete props.primaryActionAvailable;
      expect(renderComponent(props)).toMatchSnapshot();
    });
    it('renders correct markup when `primaryActionAvailable` is null', function () {
      var props = (0, _objectSpread2.default)({}, MOCK_PROPS);
      props.primaryActionAvailable = null;
      expect(renderComponent(props)).toMatchSnapshot();
    });
    it('renders correct markup when `primaryActionAvailable` is undefined', function () {
      var props = (0, _objectSpread2.default)({}, MOCK_PROPS);
      props.primaryActionAvailable = undefined;
      expect(renderComponent(props)).toMatchSnapshot();
    });
    it('renders correct markup when `primaryActionAvailable` is an empty array', function () {
      var props = (0, _objectSpread2.default)({}, MOCK_PROPS);
      props.primaryActionAvailable = [];
      expect(renderComponent(props)).toMatchSnapshot();
    });
  });
  describe('primaryContentDisplayed', function () {
    it('renders correct markup when `primaryContentDisplayed` not supplied', function () {
      var props = (0, _objectSpread2.default)({}, MOCK_PROPS);
      delete props.primaryContentDisplayed;
      expect(renderComponent(props)).toMatchSnapshot();
    });
    it('renders correct markup when `primaryContentDisplayed` is null', function () {
      var props = (0, _objectSpread2.default)({}, MOCK_PROPS);
      props.primaryContentDisplayed = null;
      expect(renderComponent(props)).toMatchSnapshot();
    });
    it('renders correct markup when `primaryContentDisplayed` is undefined', function () {
      var props = (0, _objectSpread2.default)({}, MOCK_PROPS);
      props.primaryContentDisplayed = undefined;
      expect(renderComponent(props)).toMatchSnapshot();
    });
    it('renders correct markup when `primaryContentDisplayed` is an empty array', function () {
      var props = (0, _objectSpread2.default)({}, MOCK_PROPS);
      props.primaryContentDisplayed = [];
      expect(renderComponent(props)).toMatchSnapshot();
    });
  });
  describe('destinationVerified', function () {
    it('renders correct markup when `destinationVerified` not supplied', function () {
      var props = (0, _objectSpread2.default)({}, MOCK_PROPS);
      delete props.destinationVerfied;
      expect(renderComponent(props)).toMatchSnapshot();
    });
    it('renders correct markup when `destinationVerified` is null', function () {
      var props = (0, _objectSpread2.default)({}, MOCK_PROPS);
      props.destinationVerfied = null;
      expect(renderComponent(props)).toMatchSnapshot();
    });
    it('renders correct markup when `destinationVerified` is undefined', function () {
      var props = (0, _objectSpread2.default)({}, MOCK_PROPS);
      props.destinationVerfied = undefined;
      expect(renderComponent(props)).toMatchSnapshot();
    });
    it('renders correct markup when `destinationVerified` is an empty array', function () {
      var props = (0, _objectSpread2.default)({}, MOCK_PROPS);
      props.destinationVerfied = [];
      expect(renderComponent(props)).toMatchSnapshot();
    });
  });
});
//# sourceMappingURL=uxCaptureStartView.test.js.map