"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getPolyfill = exports.polyfillServiceUrl = exports.userAgentPolyfillBlacklist = void 0;

var _browserDetect = _interopRequireDefault(require("browser-detect"));

// use mobile-detect to check browser agent name because we are using it in server-render as well

/**
 * List of useragent sub-strings that don't require a polyfill - lowercase
 */
var userAgentPolyfillBlacklist = ['chrome', 'firefox'];
/**
 * @param {String} localeCode the 'xx-XX' language code for the app
 * @return {String} the polyfill.io cdn string
 */

exports.userAgentPolyfillBlacklist = userAgentPolyfillBlacklist;

var polyfillServiceUrl = function polyfillServiceUrl(localeCode) {
  var features = ['default-3.6', // This includes a _lot_ of common polyfils - check https://polyfill.io/v2/docs/features/
  'fetch', // IE, Safari
  'Intl', "Intl.~locale.".concat(localeCode), 'Array.prototype.find', // IE
  'Array.prototype.includes', // IE
  'Object.values'];
  var flags = ['gated'];
  return "https://cdn.polyfill.io/v2/polyfill.min.js?features=".concat(features.join(), "&flags=").concat(flags.join());
};
/**
 * If the userAgent does not contain any of the blacklist strings,
 * then return the polyfill url
 *
 * @param {String} userAgent  userAgent string of the current request
 * @param {String} localeCode xx-XX locale string for current request
 * @returns {Boolean|String} the polyfill service url or false
 */


exports.polyfillServiceUrl = polyfillServiceUrl;

var getPolyfill = function getPolyfill(userAgent, localeCode) {
  return !userAgentPolyfillBlacklist.includes((0, _browserDetect.default)(userAgent).name) && polyfillServiceUrl(localeCode);
};

exports.getPolyfill = getPolyfill;
//# sourceMappingURL=browserPolyfill.js.map