"use strict";

var _dateTimeUtils = require("./dateTimeUtils");

var timeUTC = 1234567890; // fixed millisecond value

var eventOffset = -1234567; // fixed millisecond value

var runtimeDate = new Date(timeUTC + eventOffset); // time value determines whether local offset is in daylight savings

var runtimeOffset = runtimeDate.getTimezoneOffset() * 60 * 1000; // runtime-dependent millisecond offset

describe('padNumber', function () {
  it('should pad numbers less than 10', function () {
    expect(new Array(10).fill() // make an empty array
    .map(function (x, i) {
      return (0, _dateTimeUtils.padNumber)(i);
    }) // map each index to padNumber
    .every(function (x, i) {
      return x === "0".concat(i);
    }) // test that every element in the array has the expected format
    ).toBe(true);
  });
  it('should not pad numbers greater or equal to 10', function () {
    for (var pow = 1; pow < 5; pow += 1) {
      var test = Math.pow(10, pow);
      expect((0, _dateTimeUtils.padNumber)(test)).toBe(test.toString());
    }
  });
});
describe('getFormattedTime', function () {
  it('should return a local time string in the format: `HH:MM:SS`', function () {
    // Regex for formatted string `HH:MM:SS`
    var regExp = /^\d{2}:\d{2}:\d{2}$/;
    var date = new Date();
    expect((0, _dateTimeUtils.getFormattedTime)(date)).toMatch(regExp);
  });
});
describe('convertToLocalTime', function () {
  it('should return a date with UTC offset by eventOffset _and_ runtimeOffset', function () {
    var expectedTime = timeUTC + eventOffset + runtimeOffset;
    expect((0, _dateTimeUtils.convertToLocalTime)(timeUTC, eventOffset).getTime()).toBe(expectedTime);
  });
  it('should return expected date value based on time when convertToLocalTime is not passed an offset arg', function () {
    var expectedTime = timeUTC + new Date(timeUTC).getTimezoneOffset() * 60 * 1000;
    expect((0, _dateTimeUtils.convertToLocalTime)(timeUTC).getTime()).toBe(expectedTime);
  });
});
//# sourceMappingURL=dateTimeUtils.test.js.map