"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getGoogleTagManagerSnippet = exports.gtmPush = exports.getDataLayerInitSnippet = exports.IS_TEST_ACCOUNT_FLAG = void 0;

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread"));

// GTM key for the default GTM container (www.meetup.com)
var GTM_KEY = 'GTM-T2LNGD'; // public auth key for GTM Environment (production/development)

var GTM_PUBLIC_AUTH = process.env.NODE_ENV === 'production' ? 'KofUFmSzY9oFkO_VAgxnWA' : 'OtzciJkDXO73MJ5VH2mTsA'; // preview ID for the GTM Environment (production/development)

var GTM_PREVIEW_ID = process.env.NODE_ENV === 'production' ? 'env-1' : 'env-265'; // Session storage flag for isTestAccount (test accounts has @meetup.org domain in emails)

var IS_TEST_ACCOUNT_FLAG = 'isTestAccount';
/**
 * @description Gets dataLayer initialization snippet with initial values provided
 * It's important to use this snippet before getGoogleTagManagerSnippet()
 * @see {@link https://developers.google.com/tag-manager/devguide#datalayer}
 */

exports.IS_TEST_ACCOUNT_FLAG = IS_TEST_ACCOUNT_FLAG;

var getDataLayerInitSnippet = function getDataLayerInitSnippet(data) {
  return "dataLayer=[".concat(data ? JSON.stringify(data) : '', "]");
};
/**
 * @description Gets the additional "isTestAccount" field which should be added to gtmPush event payload
 * in case if user use the test account (email end with @meetup.org)
 */


exports.getDataLayerInitSnippet = getDataLayerInitSnippet;

var getIsTestAccount = function getIsTestAccount() {
  if (typeof window !== 'undefined') {
    var isTestAccount = window.sessionStorage && window.sessionStorage.getItem(IS_TEST_ACCOUNT_FLAG);
    return isTestAccount && isTestAccount === 'Yes' ? {
      isTestAccount: isTestAccount
    } : {};
  }

  return {};
};
/**
 * @description Method for passing additional variables to GTM
 * @see {@link https://developers.google.com/tag-manager/devguide}
 */


var gtmPush = function gtmPush(data) {
  if (typeof window !== 'undefined') {
    window.dataLayer = window.dataLayer || [];
    var extendedEvent = (0, _objectSpread2.default)({}, data, getIsTestAccount());
    window.dataLayer.push(extendedEvent);
  }
};
/**
 * @description Gets google tag manager JS snippet
 * @see {@link https://developers.google.com/tag-manager/quickstart}
 */


exports.gtmPush = gtmPush;

var getGoogleTagManagerSnippet = function getGoogleTagManagerSnippet() {
  var gtmKey = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : GTM_KEY;
  var gtmPublicAuth = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : GTM_PUBLIC_AUTH;
  var gtmPreviewId = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : GTM_PREVIEW_ID;
  return "(function(w,d,s,l,i){w[l]=w[l]||[];w[l].push({'gtm.start':\nnew Date().getTime(),event:'gtm.js'});var f=d.getElementsByTagName(s)[0],\nj=d.createElement(s),dl=l!='dataLayer'?'&l='+l:'';j.async=true;j.src=\n'https://www.googletagmanager.com/gtm.js?id='+i+dl+ '&gtm_auth=".concat(gtmPublicAuth, "&gtm_preview=").concat(gtmPreviewId, "&gtm_cookies_win=x';f.parentNode.insertBefore(j,f);\n})(window,document,'script','dataLayer','").concat(gtmKey, "');");
};

exports.getGoogleTagManagerSnippet = getGoogleTagManagerSnippet;
//# sourceMappingURL=googleTagManager.js.map