"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.generateEventDateForSeo = exports.generateEventLdJson = exports.generateFeeLdJson = exports.generateLocationLdJson = exports.generateOrganizationLdJson = exports.MEETUP_SWARM_LOGO_URL = exports.SCHEMA_ORG = exports.DEFAULT_TITLE = void 0;

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread"));

var _links = require("./links");

var _socialHelper = require("../../util/socialHelper");

var _dateTimeUtils = require("../dateTimeUtils");

var DEFAULT_TITLE = 'Meetup';
exports.DEFAULT_TITLE = DEFAULT_TITLE;
var SCHEMA_ORG = 'http://schema.org';
exports.SCHEMA_ORG = SCHEMA_ORG;
var MEETUP_SWARM_LOGO_URL = 'https://secure.meetupstatic.com/s/img/786824251364989575000/logo/swarm/m_swarm_630x630.png';
/**
 * Generated Object of LD-JSON of organization info
 * @see https://json-ld.org/ - to learn more about ld-json
 * @param {String} baseUrl base url of the page (protocol + hostname)
 * @param {String} localeCode locale of user
 * @param {String} route redux'd route to the current page
 * @return {Object} accumulated json object
 */

exports.MEETUP_SWARM_LOGO_URL = MEETUP_SWARM_LOGO_URL;

var generateOrganizationLdJson = function generateOrganizationLdJson(baseUrl, localeCode, route) {
  var socialLinks = (0, _socialHelper.getSocialLinks)(localeCode);
  var url = (0, _links.generateCanonicalUrl)(baseUrl, localeCode, route);
  return {
    '@type': 'Organization',
    '@context': SCHEMA_ORG,
    url: url,
    name: DEFAULT_TITLE,
    logo: MEETUP_SWARM_LOGO_URL,
    sameAs: [socialLinks.facebook, socialLinks.twitter, socialLinks.youtube, socialLinks.googlePlus, socialLinks.instagram]
  };
};
/**
 * Generated Object of LD-JSON used if event has a venue
 * @see https://json-ld.org/ - to learn more about ld-json
 * @param {Object} venue venue object associated with the event
 * @return {Object} accumulated json object
 */


exports.generateOrganizationLdJson = generateOrganizationLdJson;

var generateLocationLdJson = function generateLocationLdJson(venue) {
  var address = {
    '@type': 'PostalAddress',
    streetAddress: [venue.address_1, venue.address_2, venue.address_3].filter(function (k) {
      return k !== undefined && k !== '';
    }).join(' '),
    addressLocality: venue.city,
    postalCode: venue.zip,
    addressRegion: venue.state,
    addressCountry: venue.localized_country_name
  };
  var geo = {
    '@type': 'GeoCoordinates',
    latitude: venue.lat,
    longitude: venue.lon
  };
  return {
    location: {
      '@type': 'Place',
      name: venue.name,
      address: address,
      geo: geo
    }
  };
};
/**
 * Generated Object of LD-JSON if event has a fee associated
 * @see https://json-ld.org/ - to learn more about ld-json
 * @param {Object} fee Fee data associated with event
 * @return {Object} accumulated json object
 */


exports.generateLocationLdJson = generateLocationLdJson;

var generateFeeLdJson = function generateFeeLdJson(fee) {
  return {
    offers: {
      '@type': 'Offer',
      price: fee.amount,
      priceCurrency: fee.currency
    }
  };
};
/**
 * Generated Object of LD-JSON used for search engines to read data on page
 * @see https://json-ld.org/ - to learn more about ld-json
 * @param {Object} eventInfo event object for the page
 * @return {Object} accumulated json object
 */


exports.generateFeeLdJson = generateFeeLdJson;

var generateEventLdJson = function generateEventLdJson(eventInfo) {
  var startDate = eventInfo.time && generateEventDateForSeo(eventInfo.time, eventInfo.utc_offset);
  var endDate = eventInfo.time && eventInfo.duration && generateEventDateForSeo(eventInfo.time + eventInfo.duration, eventInfo.utc_offset);
  var offers = eventInfo.fee ? generateFeeLdJson(eventInfo.fee) : {};
  var location = eventInfo.venue ? generateLocationLdJson(eventInfo.venue) : {}; // trim description to 500 characters

  var description = (eventInfo.plain_text_no_images_description || eventInfo.description || '').substring(0, 500);
  return (0, _objectSpread2.default)({
    '@context': SCHEMA_ORG,
    '@type': 'Event',
    name: eventInfo.name,
    url: eventInfo.link,
    description: description,
    startDate: startDate,
    endDate: endDate
  }, location, offers);
};

exports.generateEventLdJson = generateEventLdJson;

var generateEventDateForSeo = function generateEventDateForSeo(time) {
  var offset = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
  var localDate = (0, _dateTimeUtils.convertToLocalTime)(time, offset);
  var localYear = localDate.getFullYear();
  var localMonth = (0, _dateTimeUtils.padNumber)(localDate.getMonth() + 1);
  var localDay = (0, _dateTimeUtils.padNumber)(localDate.getDate());
  var localTime = (0, _dateTimeUtils.getFormattedTime)(localDate).replace(/:[^:]+$/, ''); // strip the last `:` and everything after

  var offsetHoursMins = offset / (60 * 1000);
  var offsetHours = (0, _dateTimeUtils.padNumber)(parseInt(Math.abs(offsetHoursMins / 60)));
  var offsetMins = (0, _dateTimeUtils.padNumber)(Math.abs(offsetHoursMins % 60));
  var operator = offset < 0 ? '-' : '+';
  var formattedOffset = "".concat(operator).concat(offsetHours, ":").concat(offsetMins); // this will create a startDate in this format 2018-02-23T18:00+04:00

  return "".concat(localYear, "-").concat(localMonth, "-").concat(localDay, "T").concat(localTime).concat(formattedOffset);
};

exports.generateEventDateForSeo = generateEventDateForSeo;
//# sourceMappingURL=ldJson.js.map