"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread"));

var _api = require("meetup-web-mocks/lib/api");

var _ldJson = require("./ldJson");

var MOCK_VENUE = {
  name: 'some place',
  address_1: 'address 1',
  address_2: 'address 2',
  address_3: 'address 3',
  city: 'city name',
  state: 'NY',
  zip: '00000',
  country: 'usa',
  localized_country_name: 'usa'
};
var MOCK_FEE = {
  amount: 11,
  currency: 'USD'
};
describe('generateFeeLdJson', function () {
  it('should generate a ld+json object for offers', function () {
    var processedObj = (0, _ldJson.generateFeeLdJson)(MOCK_FEE);
    expect(processedObj).toMatchSnapshot();
  });
});
describe('generateLocationLdJson', function () {
  it('should generate a ld+json object for location', function () {
    var processedObj = (0, _ldJson.generateLocationLdJson)(MOCK_VENUE);
    expect(processedObj).toMatchSnapshot();
  });
});
describe('generateEventLdJson', function () {
  it('should generate a ld+json object for event', function () {
    var event = (0, _objectSpread2.default)({}, _api.MOCK_EVENT, {
      time: 1501284510,
      utc_offset: -18000000,
      // Eastern Time
      MOCK_VENUE: MOCK_VENUE,
      MOCK_FEE: MOCK_FEE
    });
    var processedObj = (0, _ldJson.generateEventLdJson)(event);
    expect(processedObj).toMatchSnapshot();
  });
});
describe('generateOrganizationLdJson', function () {
  it('should generate json with all the correct fields', function () {
    var baseUrl = 'http://www.craaazyurl.com';
    var localeCode = 'es';
    var route = '/woooo';
    var json = (0, _ldJson.generateOrganizationLdJson)(baseUrl, localeCode, route);
    expect(json).toHaveProperty('@type');
    expect(json).toHaveProperty('@context');
    expect(json).toHaveProperty('url');
    expect(json).toHaveProperty('name');
    expect(json).toHaveProperty('logo');
    expect(json).toHaveProperty('sameAs');
    expect(json.sameAs).toHaveLength(5);
  });
  it('should generate localized url and social media links', function () {
    var baseUrl = 'http://www.craaazyurl.com';
    var localeCode = 'fr-FR';
    var route = '/woooo';
    var json = (0, _ldJson.generateOrganizationLdJson)(baseUrl, localeCode, route);
    var facebookLink = json.sameAs[0];
    var twitterLink = json.sameAs[1];
    expect(json.url).toBe("".concat(baseUrl, "/").concat(localeCode).concat(route));
    expect(facebookLink).toBe('https://www.facebook.com/MeetupFR/');
    expect(twitterLink).toBe('https://twitter.com/MeetupFR/');
  });
});
describe('generateEventDateForSeo', function () {
  it('should generate date to Google SEO specs', function () {
    var timeUTC = 1559752200000; // fixed millisecond value

    var offset = -18000000; // Eastern Time

    var formattedDate = (0, _ldJson.generateEventDateForSeo)(timeUTC, offset);
    expect(formattedDate).toBe('2019-06-05T11:30-05:00');
  });
  it('should generate date with a default of +00:00 timezone if offset is undefined', function () {
    var timeUTC = 1559752200000; // fixed millisecond value

    var offset = undefined;
    var formattedDate = (0, _ldJson.generateEventDateForSeo)(timeUTC, offset);
    expect(formattedDate).toBe('2019-06-05T16:30+00:00');
  });
  it('should generate date correctly for 30 min off timezones', function () {
    var timeUTC = 1559752200000; // fixed millisecond value

    var offset = 19800000; // India + Sri Lanka

    var formattedDate = (0, _ldJson.generateEventDateForSeo)(timeUTC, offset);
    expect(formattedDate).toBe('2019-06-05T22:00+05:30');
  });
  it('should generate date correctly for 45 min off timezones', function () {
    var timeUTC = 1559752200000; // fixed millisecond value

    var offset = 31500000; // Australia/Eucla

    var formattedDate = (0, _ldJson.generateEventDateForSeo)(timeUTC, offset);
    expect(formattedDate).toBe('2019-06-06T01:15+08:45');
  });
});
//# sourceMappingURL=ldJson.test.js.map