"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.generateCanonicalUrlLinkTags = exports.generateCanonicalUrl = void 0;

var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));

var _react = _interopRequireDefault(require("react"));

var _locales = _interopRequireDefault(require("mwp-config/locales"));

/**
 * Generates array of React.element's of <link />'s containing canonical + locale urls for the path provided
 * @param  {String} baseUrl base url of the page (protocol + hostname)
 * @param  {String} localeCode   locale of user
 * @param  {String} forcedLocaleCode   locale of group
 * @param  {String} route route currently being viewed
 * @return {String}  composed canonical url
 */
var generateCanonicalUrl = function generateCanonicalUrl(baseUrl, localeCode, route, forcedLocaleCode) {
  var newLocaleCode = forcedLocaleCode || localeCode;

  if (newLocaleCode === 'en-US') {
    return "".concat(baseUrl).concat(route);
  }

  return "".concat(baseUrl, "/").concat(newLocaleCode).concat(route);
};
/**
 * Generates array of React.element's of <link />'s containing
 * canonical + locale urls for the path provided
 * @param  {String} baseUrl base url of the page (protocol + hostname)
 * @param  {String} localeCode   locale of user
 * @param  {String} forcedLocaleCode  locale of group
 * @param {Boolean} isGenerateAlternateLinks Defines if we need to generate alternate link tags for the page
 * @param  {String} route   redux'd route to the current page
 * @return {Array}  array of React.element's
 */


exports.generateCanonicalUrl = generateCanonicalUrl;

var generateCanonicalUrlLinkTags = function generateCanonicalUrlLinkTags(baseUrl, localeCode, route, isGenerateAlternateLinks) {
  var forcedLocaleCode = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : '';
  var result = [_react.default.createElement("link", {
    rel: "canonical",
    href: generateCanonicalUrl(baseUrl, localeCode, route, forcedLocaleCode),
    key: "canonical"
  })];

  if (forcedLocaleCode) {
    return result;
  }

  var localeLinks = _locales.default.reduce(function (acc, locale) {
    var locationDependentTag = _react.default.createElement("link", {
      rel: "alternate",
      hrefLang: locale == 'en-US' ? 'en' : locale,
      href: generateCanonicalUrl(baseUrl, locale, route),
      key: locale
    }); // Google recommends adding location-independent tags for each hreflang tag that includes a location
    // We skip 'es' and 'es-ES' as they are already both supported in locales array
    // and 'en-US' \ 'en-AU' as 'en' hreflang is rendered by default


    if (locale !== 'en-US' && locale !== 'en-AU' && locale !== 'es' && locale !== 'es-ES') {
      var localeParts = locale.split('-');

      if (localeParts.length === 2) {
        var locationIndependentTag = _react.default.createElement("link", {
          rel: "alternate",
          hrefLang: localeParts[0],
          href: generateCanonicalUrl(baseUrl, locale, route),
          key: localeParts[0]
        });

        return [].concat((0, _toConsumableArray2.default)(acc), [locationDependentTag, locationIndependentTag]);
      }
    }

    return [].concat((0, _toConsumableArray2.default)(acc), [locationDependentTag]);
  }, []);

  var alternateLinks = isGenerateAlternateLinks ? [].concat((0, _toConsumableArray2.default)(localeLinks), [_react.default.createElement("link", {
    rel: "alternate",
    hrefLang: "x-default",
    href: "".concat(baseUrl).concat(route),
    key: "default"
  })]) : '';
  result = [].concat((0, _toConsumableArray2.default)(result), (0, _toConsumableArray2.default)(alternateLinks));
  return result;
};

exports.generateCanonicalUrlLinkTags = generateCanonicalUrlLinkTags;
//# sourceMappingURL=links.js.map