"use strict";

var _links = require("./links");

describe('generateCanonicalUrlLinkTags', function () {
  var MOCK_BASE_URL = 'http://www.mock-base-url.com';
  var MOCK_ROUTE = '/mockroute';
  var MOCK_LOCALE_CODE = 'fr-FR';
  var MOCK_IS_GENERATE_ALTERNATE_LINKS = true;
  it('should generate locale <link />s for all locales', function () {
    var canonicalUrlMetaTags = (0, _links.generateCanonicalUrlLinkTags)(MOCK_BASE_URL, 'en-US', MOCK_ROUTE, MOCK_IS_GENERATE_ALTERNATE_LINKS);
    expect(canonicalUrlMetaTags).toMatchSnapshot();
  });
  it('should generate a canonical link tag with locale if *not* en-US', function () {
    var canonicalUrlMetaTags = (0, _links.generateCanonicalUrlLinkTags)(MOCK_BASE_URL, MOCK_LOCALE_CODE, MOCK_ROUTE, MOCK_IS_GENERATE_ALTERNATE_LINKS);
    expect(canonicalUrlMetaTags.filter(function (el) {
      return el.props.rel === 'canonical';
    })).toMatchSnapshot();
  });
  it('should generate a canonical link tag without locale if en-US', function () {
    var canonicalUrlMetaTags = (0, _links.generateCanonicalUrlLinkTags)(MOCK_BASE_URL, 'en-US', MOCK_ROUTE, MOCK_IS_GENERATE_ALTERNATE_LINKS);
    expect(canonicalUrlMetaTags.filter(function (el) {
      return el.props.rel === 'canonical';
    })).toMatchSnapshot();
  });
  it('should generate a x-default url that is baseUrl + route', function () {
    var canonicalUrlMetaTags = (0, _links.generateCanonicalUrlLinkTags)(MOCK_BASE_URL, MOCK_LOCALE_CODE, MOCK_ROUTE, MOCK_IS_GENERATE_ALTERNATE_LINKS);
    expect(canonicalUrlMetaTags.filter(function (el) {
      return el.props.hrefLang === 'x-default';
    })).toMatchSnapshot();
  });
  it('should not generate locale <link />s when isGenerateAlternateLinks = false', function () {
    var canonicalUrlMetaTags = (0, _links.generateCanonicalUrlLinkTags)(MOCK_BASE_URL, 'en-US', MOCK_ROUTE, false);
    expect(canonicalUrlMetaTags).toMatchSnapshot();
  });
});
//# sourceMappingURL=links.test.js.map