"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.generateGeoMetaData = exports.generateMetaData = exports.generateMetaTags = exports.getGroupKeywords = exports.getKeywordsByProperties = exports.DEFAULT_IMAGE_URL = exports.TWITTER_APP_ID = exports.BING_META = exports.YANDEX_META = exports.FB_APP_ID = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));

var _react = _interopRequireDefault(require("react"));

var _links = require("./links");

var FB_APP_ID = process.env.NODE_ENV === 'production' ? '2403839689' : '36212898404';
exports.FB_APP_ID = FB_APP_ID;
var YANDEX_META = {
  name: 'yandex-verification',
  value: '68c4b420dba9aa42'
};
exports.YANDEX_META = YANDEX_META;
var BING_META = {
  name: 'msvalidate.01',
  value: '386E470199B7059A6A790A75D5A03B31'
};
exports.BING_META = BING_META;
var TWITTER_APP_ID = '375990038';
exports.TWITTER_APP_ID = TWITTER_APP_ID;
var DEFAULT_IMAGE_URL = 'https://secure.meetupstatic.com/s/img/286374644891845767035/logo/meetup-logo-script-1200x630.png';
/**
 * Strips new lines and tabs from string + truncates provided
 * @param {String} str String to strip
 * @param {Number} charLen Number of char to truncate string by
 * @return {String} new string
 */

exports.DEFAULT_IMAGE_URL = DEFAULT_IMAGE_URL;

var stripAndTruncate = function stripAndTruncate() {
  var str = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  var charLen = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 200;
  return str.replace(/<(?:.|\n)*?>/gm, '').replace(/\r?\n|\r\t/g, '').substr(0, charLen);
};
/**
 * Generates array of properties off of object based on array of keys passed
 * @param {Object} item object to get values from
 * @param {Array} keys keys to pull values with
 * @return {Array} array of requested props
 */


var getKeywordsByProperties = function getKeywordsByProperties(item, keys) {
  return keys.filter(function (key) {
    return item[key];
  }).map(function (key) {
    return item[key];
  });
};
/**
 * Generates keywords from group based on group object
 * @param {Object} group group object from api
 * @return {String} keyword string to use for seo
 */


exports.getKeywordsByProperties = getKeywordsByProperties;

var getGroupKeywords = function getGroupKeywords(group) {
  var topics = group.topics || [];
  var topicKeywords = topics.map(function (topic) {
    return topic.name;
  });
  var groupKeys = ['name', 'city', 'state', 'country'];
  return [].concat((0, _toConsumableArray2.default)(topicKeywords), (0, _toConsumableArray2.default)(getKeywordsByProperties(group, groupKeys))).join(',');
};

exports.getGroupKeywords = getGroupKeywords;

var generateMetaTags = function generateMetaTags(tags) {
  return tags.map(function (meta, index) {
    return _react.default.createElement("meta", (0, _extends2.default)({}, meta, {
      key: "meta-".concat(index)
    }));
  });
};
/**
 * Generates array of basic common meta data for all pages
 * @param {String} options.appPath current pages path in apps
 * @param {String} options.baseUrl base url of the current page
 * @param {String} imageUrl An image url that will be applied to several meta tags
 * @param {String} localCode The current localeCode
 * @param {String} options.ogDescription title for og:description
 * @param {String} options.ogTitle title for og:title
 * @param {String} options.pageDescription pageDescription for the current page
 * @param {String} options.pageKeywords pageKeywords for the current page
 * @param {String} options.pageTitle pageTitle for the current page
 * @param {String} route The current route
 * @return {Array} array of meta objects or use by Helmet
 */


exports.generateMetaTags = generateMetaTags;

var generateMetaData = function generateMetaData(_ref) {
  var appPath = _ref.appPath,
      baseUrl = _ref.baseUrl,
      imageUrl = _ref.imageUrl,
      localeCode = _ref.localeCode,
      ogDescription = _ref.ogDescription,
      ogTitle = _ref.ogTitle,
      pageDescription = _ref.pageDescription,
      pageKeywords = _ref.pageKeywords,
      pageTitle = _ref.pageTitle,
      route = _ref.route;
  var desc = stripAndTruncate(pageDescription);
  var ogDesc = stripAndTruncate(ogDescription);
  return [{
    name: 'description',
    content: desc
  }, {
    name: 'keywords',
    content: pageKeywords
  }, {
    property: 'fb:app_id',
    content: FB_APP_ID
  }, {
    property: 'og:site_name',
    content: 'Meetup'
  }, {
    property: 'og:type',
    content: 'article'
  }, {
    property: 'og:title',
    content: ogTitle || pageTitle
  }, {
    property: 'og:description',
    content: ogDesc || desc
  }, baseUrl && {
    property: 'og:url',
    content: (0, _links.generateCanonicalUrl)(baseUrl, localeCode, route)
  }, {
    property: 'og:image',
    content: imageUrl
  }, {
    property: 'al:android:app_name',
    content: 'Meetup'
  }, {
    property: 'al:android:package',
    content: 'com.meetup'
  }, {
    property: 'al:ios:app_store_id',
    content: TWITTER_APP_ID
  }, {
    property: 'al:ios:app_name',
    content: 'Meetup'
  }, {
    property: 'al:web:should_fallback',
    content: 'true'
  }, appPath && {
    property: 'al:android:url',
    content: appPath
  }, appPath && {
    property: 'al:ios:url',
    content: appPath
  }, baseUrl && route && {
    property: 'al:web:url',
    content: (0, _links.generateCanonicalUrl)(baseUrl, localeCode, route)
  }, {
    property: 'twitter:card',
    content: 'summary_large_image'
  }, {
    property: 'twitter:site',
    content: '@meetup'
  }, {
    property: 'twitter:image',
    content: imageUrl
  }, {
    property: 'twitter:description',
    content: desc
  }, {
    property: 'twitter:app:id:iphone',
    content: TWITTER_APP_ID
  }, {
    property: 'twitter:app:name:iphone',
    content: 'Meetup'
  }, {
    property: 'twitter:app:id:ipad',
    content: TWITTER_APP_ID
  }, {
    property: 'twitter:app:name:ipad',
    content: 'Meetup'
  }, {
    property: 'twitter:app:id:googleplay',
    content: 'com.meetup'
  }, {
    property: 'twitter:app:name:googleplay',
    content: 'Meetup'
  }].filter(function (metaEntry) {
    return metaEntry && metaEntry.content;
  });
};
/**
 * Generates array of basic geo meta data
 * @param {Number} options.lat lat of content on page (generally group or event location)
 * @param {Number} options.lon lon of content on page (generally group or event location)
 * @param {String} options.city city of content on page (generally group or event location)
 * @param {String} options.state state of content on page (generally group or event location)
 * @param {String} options.country country of content on page (generally group or event location)
 * @return {Array} array of meta objects for use by Helmet
 */


exports.generateMetaData = generateMetaData;

var generateGeoMetaData = function generateGeoMetaData(_ref2) {
  var lat = _ref2.lat,
      lon = _ref2.lon,
      city = _ref2.city,
      state = _ref2.state,
      country = _ref2.country;
  var place = [city, state, country].filter(function (place) {
    return place;
  }).join(', ');
  return [lat && lon && {
    property: 'geo.position',
    content: "".concat(lat, ";").concat(lon)
  }, // MUP coordinates
  {
    property: 'geo.placename',
    content: place
  }, {
    property: 'geo.region',
    content: country
  }].filter(function (metaEntry) {
    return metaEntry && metaEntry.content;
  });
};

exports.generateGeoMetaData = generateGeoMetaData;
//# sourceMappingURL=metaTags.js.map