"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread"));

var _metaTags = require("./metaTags");

var MOCK_META = {
  appPath: '/mock/app/path',
  baseUrl: 'https://mock-base-url.com',
  imageUrl: 'https://www.meetup.com/mock-default-image.jpg',
  localeCode: 'fr-FR',
  pageTitle: 'mock title',
  pageDescription: 'mock description',
  pageKeywords: 'mock,keywords,comma,separated',
  route: '/mock/preview/path'
};
describe('generateMetaData', function () {
  it('matches snap', function () {
    var metaData = (0, _metaTags.generateMetaData)(MOCK_META);
    expect(metaData).toMatchSnapshot();
  });
  it('should exlude meta entries with missing content', function () {
    var emptyMetaData = (0, _metaTags.generateMetaData)([{
      property: 'mockProp2',
      content: undefined
    }, {
      property: 'mockProp2',
      content: ''
    }]);
    expect(emptyMetaData).toMatchSnapshot();
  });
});
describe('generateMetaTags', function () {
  it('matches snapshot', function () {
    var metaData = (0, _metaTags.generateMetaData)(MOCK_META);
    var metaTags = (0, _metaTags.generateMetaTags)(metaData);
    expect(metaTags).toMatchSnapshot();
  });
});
describe('generateGeoMetaData', function () {
  var MOCK_GEO = {
    city: 'mock-city',
    country: 'mock-country',
    lat: 'mock-lat',
    lon: 'mock-lon',
    state: 'mock-state'
  };
  it('matches snap', function () {
    var geoMetaData = (0, _metaTags.generateGeoMetaData)(MOCK_GEO);
    expect(geoMetaData).toMatchSnapshot();
  });
  it('should *not* set geo.position when lat or lon are missing', function () {
    var mockGeo = (0, _objectSpread2.default)({}, MOCK_GEO);
    delete mockGeo.lat;
    var geoMetaData = (0, _metaTags.generateGeoMetaData)(mockGeo);
    expect(geoMetaData).not.toEqual(expect.arrayContaining([expect.objectContaining({
      property: 'geo.postion'
    })]));
  });
  it('should exclude state and country from geo.placename when not provided', function () {
    var mockGeo = (0, _objectSpread2.default)({}, MOCK_GEO);
    delete mockGeo.state;
    delete mockGeo.country;
    var geoMetaData = (0, _metaTags.generateGeoMetaData)(mockGeo);
    expect(geoMetaData).toMatchSnapshot();
  });
  it('should exclude state from geo.placename when not provided', function () {
    var mockGeo = (0, _objectSpread2.default)({}, MOCK_GEO);
    delete mockGeo.state;
    var geoMetaData = (0, _metaTags.generateGeoMetaData)(mockGeo);
    expect(geoMetaData).toMatchSnapshot();
  });
});
describe('getGroupKeywords', function () {
  var group = {
    name: 'Test group',
    city: 'Albuquerque',
    state: 'NM',
    country: 'us'
  };
  it('matches snap for group with topics', function () {
    var keywords = (0, _metaTags.getGroupKeywords)((0, _objectSpread2.default)({}, group, {
      topics: [{
        name: 'hiking'
      }, {
        name: 'beagles'
      }, {
        name: 'programming'
      }]
    }));
    expect(keywords).toMatchSnapshot();
  });
  it('matches snap for group with no topics', function () {
    var keywords = (0, _metaTags.getGroupKeywords)(group);
    expect(keywords).toMatchSnapshot();
  });
});
//# sourceMappingURL=metaTags.test.js.map